First snapshot of FIO for Windows

Signed-off-by: Jens Axboe <jaxboe@fusionio.com>
diff --git a/ioengine.h b/ioengine.h
index a0c7e2b..48a042b 100644
--- a/ioengine.h
+++ b/ioengine.h
@@ -125,7 +125,7 @@
 	FIO_NODISKUTIL  = 1 << 4,       /* diskutil can't handle filename */
 	FIO_UNIDIR	= 1 << 5,	/* engine is uni-directional */
 	FIO_NOIO	= 1 << 6,	/* thread does only pseudo IO */
-	FIO_SIGQUIT	= 1 << 7,	/* needs SIGQUIT to exit */
+	FIO_SIGTERM	= 1 << 7,	/* needs SIGTERM to exit */
 	FIO_PIPEIO	= 1 << 8,	/* input/output no seekable */
 	FIO_BARRIER	= 1 << 9,	/* engine supports barriers */
 	FIO_MEMALIGN	= 1 << 10,	/* engine wants aligned memory */